@@ -26,6 +26,21 @@ class math_:
     def square_root(x : float):
         return float(x) ** 0.5
 
+    def mtn_tb(x, y, ini = 0):
+        y += 1
+        z = []
+        for i in range(ini, y):
+            v = x * i
+            z.append(v)
+        return z
+
+    def n_to_n(x, y):
+        y += 1
+        z = []
+        for i in range(x, y):
+            z.append(i)
+        return z
+
 class utils:
 
     def clean():
